from __future__ import annotations
from typing import TYPE_CHECKING
import json
import icalendar
from datetime import datetime, timedelta

# Import for type hints only
if TYPE_CHECKING:
    from .device import device


class ScheduleEndpoint:

    def __init__(self, device: device) -> None:

        self.api = device.api
        self.api.base_url = "http://" + self.api.host + "/vapix"

        self.schedules = {}

        self.update_schedules()

    def update_schedules(self):

        resp = self.api._send_request("schedule/GetScheduleInfoList")

        for schedule in resp['ScheduleInfo']:

            if schedule['token'] in self.schedules.keys():
                self.schedules[schedule['token']].get_schedule()
            else:
                self.schedules[schedule['token']] = Schedule(token=schedule['token'], schedule=self)

    def create_schedule(self, token, name = "", operator="addition") -> None:

        self.schedules[token] = Schedule(token=token, name=name, schedule=self)

        self.schedules[token].operator = operator
        self.schedules[token].enabled = True

        self.schedules[token].update()
        self.schedules[token].get_schedule()

    def remove_schedule(self, token, force=False):

        if self.schedules[token].enabled:

            if len(self.schedules[token].calendar.events) == 0:

                resp = self.api._send_request(
                    ("schedule"),
                    method="POST",
                    params={"axsch:RemoveSchedule":{"Token":[token]}}
                )

                del self.schedules[token]

            elif force:

                resp = self.api._send_request(
                    ("schedule"),
                    method="POST",
                    params={"axsch:RemoveSchedule":{"Token":[token]}}
                )

                del self.schedules[token]

            self.update_schedules()

    def remove_pastschedules(self):

        for token in list(self.schedules.keys()):

            if self.schedules[token].enabled:
                
                self.schedules[token].remove_pastevents()
                self.schedules[token].get_schedule()
                self.remove_schedule(token=token)

    def enable_schedules(self, token):

        if token in self.schedules.keys():

            self.schedules[token].enabled = True
            self.schedules[token].get_schedule()

class Schedule:

    def __init__(self, schedule: ScheduleEndpoint, token = "", name = "") -> None:

        self.api = schedule.api

        self.name = name
        self.token = token
        self.description = ""
        self.attribute = []

        self.operator = "addition"
        self.calendar = icalendar.Calendar()

        self.limit = 10000
        self.postfix = 1
        self.parent = token
        self.children = set()
        self.enabled = False
        self.removal_limit = 30

        self.get_schedule()

    def get_schedule(self) -> None:

        if self.enabled:
            resp = self.api._send_request("schedule/GetSchedule", params={"Token": self.token})

            if len(resp['Schedule']) == 0:
                self.calendar = icalendar.Calendar()

                return None

            self.name = resp['Schedule'][0]['Name']
            self.description = resp['Schedule'][0]['Description']
            self.attribute = resp['Schedule'][0]['Attribute']

            if resp['Schedule'][0]['ScheduleDefinition'] != '':
                schedule = resp['Schedule'][0]['ScheduleDefinition']
                self.operator = "addition"

            elif resp['Schedule'][0]['ExceptionScheduleDefinition']:
                schedule = resp['Schedule'][0]['ExceptionScheduleDefinition']
                self.operator = "subtraction"

            self.calendar = icalendar.Calendar.from_ical(schedule)

    def get_ical(self) -> str:

        ical = icalendar.Calendar.to_ical(self.calendar).decode("utf-8")

        return ical.replace("CATEGORIES:\r\n","")

    def update(self) -> None:

        if self.enabled:
            if self.operator == "addition":
                scheduledefinition = self.get_ical()
                exceptionscheduledefinition = ""
            else:
                scheduledefinition = ""
                exceptionscheduledefinition = self.get_ical()

            resp = self.api._send_request(
                ("schedule"),
                method="POST",
                params={
                    "axsch:SetSchedule": {
                        "Schedule":[
                        {
                            "Name": self.name,
                            "Description": "",
                            "ScheduleDefinition": scheduledefinition,
                            "ExceptionScheduleDefinition": exceptionscheduledefinition,
                            "Attribute":[],
                            "token": self.token
                        }
                        ]
                    }
                }
            )

    def add_event(self, name, start, end, rrules = "") -> None:

        event = icalendar.Event()

        event.add('summary', name)
        event.add('dtstart', start.replace(tzinfo=None))
        event.add('dtend', end.replace(tzinfo=None))
        event.add('dtstamp', datetime.now())

        if rrules != "":
            event.add('rrules', rrules)

        self.get_schedule()

        if not self.check_exists(event=event):
            self.calendar.add_component(event)
        else:
            return 1

        if len(self.get_ical()) <= self.limit:
            self.update()
            return 0
        else:
            current = self.postfix
            self.postfix += 1
            
            if self.name.endswith(str(current)):
                self.name = self.name.replace((" " + str(current)), (" " + str(self.postfix)))
                self.token = self.token.replace(("_" + str(current)), ("_" + str(self.postfix)))
            else:
                self.name = self.name + " " + str(self.postfix)
                self.token = self.token + "_" + str(self.postfix)
            
            self.get_schedule()
            self.children.add(self.token)

            self.add_event(name=name, start=start, end=end, rrules=rrules)

    def check_exists(self, event) -> bool:

        for e in self.calendar.events:

            if e['SUMMARY'] == event['SUMMARY'] and e.start == event.start and e.end == event.end:
                return True

    def remove_events(self, events: list) -> None:

        calendar = icalendar.Calendar()

        for event in self.calendar.events:

            if event not in events:

                calendar.add_component(event)

        self.calendar = calendar
        self.update()

    def remove_pastevents(self) -> None:

        now = datetime.now() - timedelta(self.removal_limit)
        remove = list()

        for event in self.calendar.events:

            if event.end < now:

                remove.append(event)

        self.remove_events(events=remove)



from __future__ import annotations
from typing import TYPE_CHECKING

# Import for type hints only
if TYPE_CHECKING:
    from .device import device

class PTZControl:

    def __init__(self, api: VapixAPI) -> None:
        self.api = api
        
    def get_current_position(self) -> tuple(float, float, float):
        """
        Gets the current position of the camera.

        Returns:
            tuple: A tuple containing the current pan, tilt, and zoom values.
        """
        resp = self.api._send_request('com/ptz.cgi', params={'query': 'position'})
        pan = float(resp.split()[0].split('=')[1])
        tilt = float(resp.split()[1].split('=')[1])
        zoom = float(resp.split()[2].split('=')[1])
        ptz_tuple = (pan, tilt, zoom)

        return ptz_tuple
    
    def get_current_ptz(self) -> str:
        """
        Gets the current position of the camera.

        Returns:
            str: A string containing the current pan, tilt, and zoom values.
        """
        resp = self.api._send_request('com/ptz.cgi', params={'query': 'position'})
        return resp
    
    def absolute_move(self, pan: float, tilt: float, zoom: float, speed: float) -> None:
        """
        Moves the camera to the specified position.

        Args:
            pan (float): The pan value to move to.
            tilt (float): The tilt value to move to.
            zoom (float): The zoom value to move to.
            speed (float): The speed to move at.
        """
        params = {'pan': pan, 'tilt': tilt, 'zoom': zoom, 'speed': speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def relative_move(self, pan: float, tilt: float, zoom: float, speed: float) -> None:
        """
        Moves the camera by the specified amount.

        Args:
            pan (float): The pan value to move by.
            tilt (float): The tilt value to move by.
            zoom (float): The zoom value to move by.
            speed (float): The speed to move at.
        """
        params = {'rpan': pan, 'rtilt': tilt, 'rzoom': zoom, 'speed': speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def continuous_move(self, pan_speed: int, tilt_speed: int, zoom_speed: int) -> None:
        """
        Moves the camera continuously in the specified direction.

        Args:
            pan_speed (int): The pan speed to move at.
            tilt_speed (int): The tilt speed to move at.
            zoom_speed (int): The zoom speed to move at.
        """
        pan_tilt = str(pan_speed) + "," + str(tilt_speed)
        params = {'continuouspantiltmove': pan_tilt, 'continuouszoommove': zoom_speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def continuous_pantilt(self, pan_speed: int, tilt_speed: int) -> None:
        """
        Moves the camera continuously in the specified direction.

        Args:
            pan_speed (int): The pan speed to move at.
            tilt_speed (int): The tilt speed to move at.
        """
        pt_speed = str(pan_speed) + "," + str(tilt_speed)
        params = {'continuouspantiltmove': pt_speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def continuous_zoom(self, zoom_speed: int):
        """
        Moves the camera continuously in the specified direction.

        Args:
            zoom_speed (int): The zoom speed to move at.
        """
        params = {'continuouszoommove': zoom_speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def continuous_focus(self, focus_speed: int):
        """
        Moves the camera continuously in the specified direction.

        Args:
            focus_speed (int): The focus speed to move at.
        """
        params = {'continuousfocusmove': focus_speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def continuous_iris(self, iris_speed: int):
        """
        Moves the camera continuously in the specified direction.

        Args:
            iris_speed (int): The iris speed to move at.
        """
        params = {'continuousirismove': iris_speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def continuous_brightness(self, brightness_speed: int):
        """
        Moves the camera continuously in the specified direction.

        Args:
            brightness_speed (int): The brightness speed to move at.
        """
        params = {'continuousbrightnessmove': brightness_speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def stop_move(self):
        """
        Stops all movement of the camera.
        """
        self.api._send_request('com/ptz.cgi', params={'continuouspantiltmove': '0,0', 'continuouszoommove': '0'})
        
    def center_move(self, x_pos: int, y_pos: int, speed: int):
        """
        Moves the camera to the specified position.

        Args:
            x_pos (int): The x position to move to.
            y_pos (int): The y position to move to.
            speed (int): The speed to move at.
        """
        params = {'center': str(x_pos) + ',' + str(y_pos), 'speed': speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def area_zoom(self, x_pos: int, y_pos: int, zoom: int, speed: int):
        """
        Moves the camera to the specified position and zoom.

        Args:
            x_pos (int): The x position to move to.
            y_pos (int): The y position to move to.
            zoom (int): The zoom value to move to.
            speed (int): The speed to move at.
        """
        params = {'areazoom': str(x_pos) + ',' + str(y_pos) + ',' + str(zoom), 'speed': speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def move(self, position: str, speed: int):
        """
        Moves the camera to the specified position.

        Args:
            position (str): The position to move to.
            speed (int): The speed to move at.
        """
        params = {'move': position, 'speed': speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def set_move_speed(self, speed: int):
        """
        Sets the speed of the camera.

        Args:
            speed (int): The speed to move at.
        """
        if speed < 0 or speed > 100:
            raise ValueError("Speed must be between 0 and 100.")
        params = {'speed': speed}
        self.api._send_request('com/ptz.cgi', params=params)
        
    def go_home(self, speed: int):
        """
        Moves the camera to the home position.

        Args:
            speed (int): The speed to move at.
        """
        params = {'move': 'home', 'speed': speed}
        self.api._send_request('com/ptz.cgi', params=params)

    def ptz_enabled(self, channel: int = 1):
        """
        Checks if PTZ is enabled on the camera.

        Args:
            channel (int, optional): The channel to check. Defaults to 1.

        Returns:
            str: List of available commands if enabled, empty string if disabled.
        """
        resp = self.api._send_request('com/ptz.cgi', params={'info': channel, 'camera': 1})
        return resp
    
    def set_iris(self, iris_level: int = 1750) -> bool:
        """
        Sets the iris to the specified value.

        Args:
            enabled (bool, optional): Whether to enable or disable the iris. Defaults to True.
        """
        if iris_level < 0 or iris_level > 9999:
            raise ValueError("Iris level must be between 0 and 9999.")
        params = {'iris': iris_level}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def set_focus(self, focus_level: int) -> bool:
        """
        Sets the focus to the specified value.

        Args:
            focus_level (int): The focus level to set.
        """
        if focus_level < 0 or focus_level > 9999:
            raise ValueError("Focus level must be between 0 and 9999.")
        params = {'focus': focus_level}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def set_zoom(self, zoom_level: int) -> bool:
        """
        Sets the zoom to the specified value.

        Args:
            zoom_level (int): The zoom level to set.
        """
        if zoom_level < 0 or zoom_level > 9999:
            raise ValueError("Zoom level must be between 0 and 9999.")
        params = {'zoom': zoom_level}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def set_brightness(self, brightness_level: int) -> bool:
        """
        Sets the brightness to the specified value.

        Args:
            brightness_level (int): The brightness level to set.
        """
        if brightness_level < 0 or brightness_level > 9999:
            raise ValueError("Brightness level must be between 0 and 9999.")
        params = {'brightness': brightness_level}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def set_autofocus(self, enabled: bool = True):
        """
        Enables or disables autofocus.

        Args:
            enabled (bool, optional): Whether to enable or disable autofocus. Defaults to True.
        """
        if enabled:
            enabled = 'on'
        else:
            enabled = 'off'
        params = {'autofocus': enabled}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def set_autoiris(self, enabled: bool = True):
        """
        Enables or disables autoiris.

        Args:
            enabled (bool, optional): Whether to enable or disable autoiris. Defaults to True.
        """
        if enabled:
            enabled = 'on'
        else:
            enabled = 'off'
        params = {'autoiris': enabled}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def set_current_preset_name(self, preset_name):
        """
        Associates the current position to <preset name> as a preset position in the Axis product.

        Args:
            preset_name (str): The name of the preset to set.
        """
        params = {'setserverpresetname': preset_name}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def set_current_preset_no(self, preset_number):
        """
        Saves the current position as a preset position number in the Axis product.

        Args:
            preset_number (int): The number of the preset to set.
        """
        params = {'setserverpresetno': preset_number}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def rename_preset_number(self, preset_number, preset_name):
        """
        Renames a preset position number in the Axis product.

        Args:
            preset_number (int): The number of the preset to rename.
            preset_name (str): The new name of the preset.
        """
        params = {'renameserverpresetno': preset_name, 'newname': preset_number}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def set_home(self):
        """
        Sets the current position as the home position.
        """
        self.api._send_request('com/ptz.cgi', params={'home': 'yes'})
        return True
    
    def remove_server_preset_name(self, preset_name):
        """
        Removes a preset position name from the Axis product.

        Args:
            preset_name (str): The name of the preset to remove.
        """
        params = {'removeserverpresetname': preset_name}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def remove_server_preset_no(self, preset_number):
        """
        Removes a preset position number from the Axis product.

        Args:
            preset_number (int): The number of the preset to remove.
        """
        params = {'removeserverpresetno': preset_number}
        self.api._send_request('com/ptz.cgi', params=params)
        return True
    
    def set_device_preset(self, preset_number):
        """
        Bypasses the presetpos interface and tells the device to save its current position as preset position 
        <preset pos> directly in the device, where <preset pos> is a device-specific preset position number. 
        This may also be a device-specific special function.

        Args:
            preset_number (int): The number of the preset to move to.
        """
        params = {'setdevicepreset': preset_number}
        self.api._send_request('com/ptz.cgi', params=params)
        return True


from __future__ import annotations
from typing import TYPE_CHECKING

import xml.etree.ElementTree as ET

# Import for type hints only
if TYPE_CHECKING:
    from .device import device


class GeolocationAPI:
    def __init__(self, api: VapixAPI) -> None:
        self.api = api
        self.endpoint = "geolocation"

    def get_position(self):
        resp = self.api._send_request_vanilla(self.endpoint + "/get.cgi")
        print(resp)

        root = ET.fromstring(resp)

        lat = float(root.find(".//Lat").text)
        lon = float(root.find(".//Lng").text)
        heading = float(root.find(".//Heading").text)

        valid_position_str = root.find(".//ValidPosition").text.strip()
        valid_position = False if valid_position_str.lower() == "false" else True

        valid_heading_str = root.find(".//ValidHeading").text.strip()
        valid_heading = False if valid_heading_str.lower() == "false" else True

        return {
            "lat": lat,
            "lon": lon,
            "heading": heading,
            "valid_position": valid_position,
            "valid_heading": valid_heading,
        }

    def set_position(self, lat: float, lon: float, heading: float = 0, text: str = ""):
        resp = self.api._send_request_vanilla(
            self.endpoint + "/set.cgi",
            method="POST",
            params={
                "lat": lat,
                "lng": lon,
                "heading": heading,
                "text": text,
            },
        )
        print(resp)



from __future__ import annotations
from typing import TYPE_CHECKING

# Import for type hints only
if TYPE_CHECKING:
    from .device import device


class DoorControl:

    def __init__(self, device: device) -> None:

        self.api = device.api
        self.api.base_url = "http://" + self.api.host + "/vapix"

        self.doors = {}

        self.get_doors()

    def get_doors(self):
        """
        Gets the door info.

        Returns:
            list: A dictionary containing door info.
        """
        resp = self.api._send_request(
            "doorcontrol/GetDoorInfoList",
        )

        for door in resp['DoorInfo']:

            self.doors[door['Name']] = Door(token=door['token'], controller=self)

class Door:

    def __init__(self, token, controller: DoorControl) -> None:

        self.controller = controller

        self.actions_table = {
            "Blocked": ("Block","DoubleLock", "Lock", "LockDown", "LockDownRelease", "LockOpen", "LockOpenRelease", "Unlock",),
            "DoubleLocked": ("Block","DoubleLock","Lock","LockDown","LockDownRelease","LockOpen","LockOpenRelease","Unlock"),
            "Locked": ("Block", "DoubleLock","Lock","LockDown", "LockDownRelease", "LockOpen", "LockOpenRelease", "Unlock",),
            "LockedDown": ("LockDown","LockDownRelease",),
            "LockedDownRelease": ("Block", "DoubleLock", "Lock", "LockDown","LockDownRelease", "LockOpen", "LockOpenRelease", "Unlock",),
            "LockedOpen": ("LockOpen", "LockOpenRelease",),
            "LockedOpenRelease": ("Block", "DoubleLock", "Lock", "LockDown", "LockOpen", "LockOpenRelease", "Unlock",),
            "Unlocked": ("Block", "DoubleLock", "Lock", "LockDown", "LockDownRelease", "LockOpen", "LockOpenRelease","Unlock",),
        }

        self.actions = ("Block","DoubleLock","Lock","LockDown","LockDownRelease","LockOpen","LockOpenRelease","Unlock")

        self.Name = 'Door'
        self.Description = 'Door'
        self.Capabilities = {}
        self.token = token
        
        self.DoorPhysicalState = False
        self.Alarm = False
        self.Mode = False

        self.LastUpdate = True
        self.Status = 'Door Created'

        self.unlockschedules = set()
        
        self.update_info()
        self.update_state()
        self.get_unlockschedules()

    def _check_action(self, token, action) -> None:
        """
        Gets the door info.

        Returns:
            list: A dictionary containing door state info.
        """

        if action in self.actions_table[self.Mode] and self.Capabilities[action]:
            return True
        else:
            return False
    
    def update_info(self) -> None:
        """
        Gets the door info.

        Returns:
            list: A dictionary containing door info.
        """
        resp = self.controller.api._send_request(
            "doorcontrol/GetDoorInfo",
            params={"Token": self.token},
        )

        self.Name = resp['DoorInfo'][0]['Name']
        self.Description = resp['DoorInfo'][0]['Description']
        self.Capabilities = resp['DoorInfo'][0]['Capabilities']
        self.token = resp['DoorInfo'][0]['token']

    def update_state(self) -> None:
        """
        Gets the door state info.

        Returns:
            list: A dictionary containing door state info.
        """
        resp = self.controller.api._send_request(
            "doorcontrol/GetDoorState",
            params={"Token": self.token},
        )

        if self.Capabilities['DoorMonitor']:
            self.DoorPhysicalState = resp['DoorState']['DoorPhysicalState']
        if self.Capabilities['Alarm']:
            self.Alarm = resp['DoorState']['Alarm']

        self.Mode = resp['DoorState']['DoorMode']

    def set_mode(self, action) -> None:
        """
        Set Door Mode.
        """

        if action in self.actions and self._check_action(token=self.token, action=action):

            resp = self.controller.api._send_request(
                ("doorcontrol/" + action + "Door"),
                params={"Token": self.token},
            )

            self._get_state()

            if self.Mode.startswith(action):
                self.LastUpdate = True
                self.Status = "State Updated"
            else:
                self.LastUpdate = False
                self.Status = "State Not Updated"

        else:

            self.LastUpdate = False
            self.Status = "Action Not Supported"

    def get_unlockschedules(self) -> None:
        """
        Get Unlock Schedules for Door.
        """

        resp = self.controller.api._send_request(
            endpoint="doorcontrol",
            method="POST",
            params={"axtdc:GetDoorScheduleConfiguration":{"Token":[self.token]}}
        )

        self.unlockschedules = set(resp['DoorScheduleConfiguration'][0]['DoorSchedule'][0]['ScheduledState'][0]['ScheduleToken'])

    def set_unlockschedules(self, token="", reset=False):

        if reset:
            self.unlockschedules = set()

        if type(token) is str:
            self.unlockschedules.add(token)
        elif type(token) is list:
            self.unlockschedules.update(token)
        
        resp = self.controller.api._send_request(
            endpoint="doorcontrol",
            method="POST",
            params={
                "axtdc:SetDoorScheduleConfiguration": {
                    "DoorScheduleConfiguration": [
                    {
                        "token": self.token,
                        "Name": '',
                        "Description": '',
                        "DoorSchedule": [
                        {
                            "ScheduledState": [
                            {
                                "ScheduleToken": list(self.unlockschedules),
                                "EnterAction": "Unlock"
                            },
                            ],
                            "PriorityLevel": ''
                        }
                        ]
                    }
                    ]
                }
            }
        )

        self.get_unlockschedules()



import time
import requests
import json

from requests.auth import HTTPDigestAuth

class api:
    """
    A class that provides an interface to interact with Axis cameras using the VAPIX API.

    Attributes:
    -----------
    host : str
        IP address or domain name of the camera.
    user : str
        Username for the camera's API authentication.
    password : str
        Password for the camera's API authentication.
    base_url : str
        Base URL for accessing the VAPIX API endpoints.
    session : requests.Session
        Session object for handling HTTP requests with authentication.
    doorcontrol : DoorControl
        Instance for controlling Door Controller.
    """

    def __init__(self, host, user, password, timeout=5):
        """
        Initializes the VapixAPI with host, user, and password credentials.

        Parameters:
        -----------
        host : str
            IP address or domain name of the camera.
        user : str
            Username for the camera's API authentication.
        password : str
            Password for the camera's API authentication.
        timeout : int, optional
            Timeout for HTTP requests (default is 5 seconds).
        """
        self.host = host
        self.user = user
        self.password = password
        self.base_url = 'http://' + self.host + '/axis-cgi'
        self.session = requests.Session()
        self.session.auth = HTTPDigestAuth(self.user, self.password)
        self.session.timeout = timeout

    def _send_request(self, endpoint, method="GET", params=None):
        """
        Send a request to a specific VAPIX API endpoint

        Parameters:
        -----------
        endpoint : str
            The endpoint to which the request is sent.
        method : str, optional
            HTTP request method (default is "GET").
        params : dict, optional
            Parameters to be included in the request.

        Returns:
        --------
        str
            Response text from the request.

        Raises:
        -------
        requests.RequestException
            If the request encounters an error.
        """
        url = f"{self.base_url}/{endpoint}"

        try:
            if method == "GET":
                response = self.session.get(url, params=params)
            elif method == "POST":
                response = self.session.post(url, json=params)
            response.raise_for_status()
            return json.loads(response.text)
        except requests.exceptions.HTTPError:
            raise Exception(response.text)
        except requests.RequestException as e:
            raise e



from .api import api
from .DoorControl import DoorControl
from .Schedule import ScheduleEndpoint

class a1001:
    """
    A class that provides an interface to interact with Axis A1001
    """

    def __init__(self, host, user, password, timeout=5):
        """
        Initializes the Axis A1001
        """
        self.api = api(host=host, user=user, password=password, timeout=timeout)

        self.doorcontrol = DoorControl(self)
        self.schedule = ScheduleEndpoint(self)
